==> pointblank_0.5.1.tar.gz: pointblank/tests/testthat/aedes_aegypti_core_55_1d/SELECT-e9a89a.R <==
structure(list(asm_seq_region_id = c(1L, 2L, 3L, 4L, 5L, 6L, 
6L, 6L, 6L, 6L, 7L, 8L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 
9L, 10L, 11L, 12L, 13L, 13L, 13L, 13L, 13L, 13L, 13L, 13L, 13L, 
13L, 13L, 13L, 13L, 13L, 13L, 13L, 14L, 14L, 14L, 14L, 14L, 15L, 
16L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 
17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 18L, 18L, 
19L, 20L, 21L, 22L, 23L, 23L, 23L, 23L, 23L, 23L), cmp_seq_region_id = c(39968L, 
40879L, 40445L, 40374L, 39809L, 35632L, 35633L, 35634L, 35635L, 
35636L, 40466L, 38059L, 12596L, 12597L, 12598L, 12599L, 12600L, 
12601L, 12602L, 12603L, 12604L, 12605L, 12606L, 12607L, 12608L, 
12609L, 12610L, 12611L, 12612L, 12613L, 12614L, 12615L, 12616L, 
12617L, 12618L, 12619L, 12620L, 12621L, 12622L, 40166L, 39790L, 
40399L, 32577L, 32578L, 32579L, 32580L, 32581L, 32582L, 32583L, 
32584L, 32585L, 32586L, 32587L, 32588L, 32589L, 32590L, 32591L, 
32592L, 32341L, 32342L, 32343L, 32344L, 32345L, 40888L, 38889L, 
30630L, 30631L, 30632L, 30633L, 30634L, 30635L, 30636L, 30637L, 
30638L, 30639L, 30640L, 30641L, 30642L, 30643L, 30644L, 30645L, 
30646L, 30647L, 30648L, 30649L, 30650L, 30651L, 30652L, 37761L, 
37762L, 40937L, 40051L, 39129L, 39856L, 10792L, 10793L, 10794L, 
10795L, 10796L, 10797L), asm_start = c(1L, 1L, 1L, 1L, 1L, 1L, 
14528L, 28441L, 45948L, 69140L, 1L, 1L, 1L, 30481L, 100061L, 
110054L, 252144L, 461393L, 489701L, 574647L, 619755L, 637075L, 
804580L, 1045035L, 1061699L, 1245902L, 1249229L, 1258009L, 1300499L, 
1416006L, 1505788L, 1528681L, 1544647L, 1567109L, 1913447L, 2023909L, 
2074330L, 2114727L, 2152671L, 1L, 1L, 1L, 1L, 32817L, 39639L, 
43455L, 62786L, 109280L, 164218L, 186821L, 212474L, 219096L, 
230024L, 243272L, 262441L, 282110L, 287796L, 339568L, 1L, 86803L, 
237748L, 246450L, 287305L, 1L, 1L, 1L, 178867L, 199501L, 207062L, 
209953L, 229249L, 231897L, 246654L, 248848L, 255126L, 261949L, 
265918L, 269198L, 312728L, 320832L, 358447L, 367745L, 370327L, 
380843L, 384989L, 398124L, 401205L, 404927L, 1L, 26372L, 1L, 
1L, 1L, 1L, 1L, 73656L, 79725L, 90824L, 95274L, 99904L), asm_end = c(5950L, 
3995L, 5177L, 5315L, 6235L, 4981L, 27818L, 45534L, 68264L, 130898L, 
5138L, 17020L, 30214L, 99717L, 109953L, 252043L, 461292L, 489600L, 
574546L, 619654L, 635391L, 804479L, 1044934L, 1061598L, 1245801L, 
1248774L, 1255939L, 1296194L, 1411355L, 1505311L, 1528580L, 1544546L, 
1567008L, 1913346L, 2023808L, 2074229L, 2114626L, 2152570L, 2181600L, 
5629L, 6264L, 5275L, 11603L, 39538L, 42705L, 57119L, 105678L, 
164117L, 186720L, 211604L, 218995L, 229730L, 242897L, 262044L, 
268076L, 286925L, 326640L, 346844L, 86702L, 236887L, 241797L, 
285058L, 304118L, 3951L, 8848L, 172544L, 199351L, 204571L, 209542L, 
228016L, 231274L, 246407L, 248747L, 251009L, 261848L, 265107L, 
268385L, 312594L, 320332L, 358306L, 367137L, 370091L, 380152L, 
384474L, 397963L, 400557L, 404679L, 417807L, 5977L, 42373L, 3581L, 
5829L, 7936L, 6150L, 15203L, 79624L, 89913L, 94045L, 98912L, 
104709L), cmp_start = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), cmp_end = c(5950L, 3995L, 
5177L, 5315L, 6235L, 4981L, 13291L, 17094L, 22317L, 61759L, 5138L, 
17020L, 30214L, 69237L, 9893L, 141990L, 209149L, 28208L, 84846L, 
45008L, 15637L, 167405L, 240355L, 16564L, 184103L, 2873L, 6711L, 
38186L, 110857L, 89306L, 22793L, 15866L, 22362L, 346238L, 110362L, 
50321L, 40297L, 37844L, 28930L, 5629L, 6264L, 5275L, 11603L, 
6722L, 3067L, 13665L, 42893L, 54838L, 22503L, 24784L, 6522L, 
10635L, 12874L, 18773L, 5636L, 4816L, 38845L, 7277L, 86702L, 
150085L, 4050L, 38609L, 16814L, 3951L, 8848L, 172544L, 20485L, 
5071L, 2481L, 18064L, 2026L, 14511L, 2094L, 2162L, 6723L, 3159L, 
2468L, 43397L, 7605L, 37475L, 8691L, 2347L, 9826L, 3632L, 12975L, 
2434L, 3475L, 12881L, 5977L, 16002L, 3581L, 5829L, 7936L, 6150L, 
15203L, 5969L, 10189L, 3222L, 3639L, 4806L), ori = c(1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L)), class = "data.frame", row.names = c(NA, -100L))

==> pointblank_0.12.3.tar.gz: pointblank/tests/testthat/aedes_aegypti_core_55_1d/SELECT-e9a89a.R <==
structure(list(asm_seq_region_id = c(1L, 2L, 3L, 4L, 5L, 6L, 
6L, 6L, 6L, 6L, 7L, 8L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 
9L, 10L, 11L, 12L, 13L, 13L, 13L, 13L, 13L, 13L, 13L, 13L, 13L, 
13L, 13L, 13L, 13L, 13L, 13L, 13L, 14L, 14L, 14L, 14L, 14L, 15L, 
16L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 
17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 17L, 18L, 18L, 
19L, 20L, 21L, 22L, 23L, 23L, 23L, 23L, 23L, 23L),
cmp_seq_region_id = c(39968L, 
40879L, 40445L, 40374L, 39809L, 35632L, 35633L, 35634L, 35635L, 
35636L, 40466L, 38059L, 12596L, 12597L, 12598L, 12599L, 12600L, 
12601L, 12602L, 12603L, 12604L, 12605L, 12606L, 12607L, 12608L, 
12609L, 12610L, 12611L, 12612L, 12613L, 12614L, 12615L, 12616L, 
12617L, 12618L, 12619L, 12620L, 12621L, 12622L, 40166L, 39790L, 
40399L, 32577L, 32578L, 32579L, 32580L, 32581L, 32582L, 32583L, 
32584L, 32585L, 32586L, 32587L, 32588L, 32589L, 32590L, 32591L, 
32592L, 32341L, 32342L, 32343L, 32344L, 32345L, 40888L, 38889L, 
30630L, 30631L, 30632L, 30633L, 30634L, 30635L, 30636L, 30637L, 
30638L, 30639L, 30640L, 30641L, 30642L, 30643L, 30644L, 30645L, 
30646L, 30647L, 30648L, 30649L, 30650L, 30651L, 30652L, 37761L, 
37762L, 40937L, 40051L, 39129L, 39856L, 10792L, 10793L, 10794L, 
10795L, 10796L, 10797L), asm_start = c(1L, 1L, 1L, 1L, 1L, 1L, 
14528L, 28441L, 45948L, 69140L, 1L, 1L, 1L, 30481L, 100061L, 
110054L, 252144L, 461393L, 489701L, 574647L, 619755L, 637075L, 
804580L, 1045035L, 1061699L, 1245902L, 1249229L, 1258009L, 1300499L, 
1416006L, 1505788L, 1528681L, 1544647L, 1567109L, 1913447L, 2023909L, 
2074330L, 2114727L, 2152671L, 1L, 1L, 1L, 1L, 32817L, 39639L, 
43455L, 62786L, 109280L, 164218L, 186821L, 212474L, 219096L, 
230024L, 243272L, 262441L, 282110L, 287796L, 339568L, 1L, 86803L, 
237748L, 246450L, 287305L, 1L, 1L, 1L, 178867L, 199501L, 207062L, 
209953L, 229249L, 231897L, 246654L, 248848L, 255126L, 261949L, 
265918L, 269198L, 312728L, 320832L, 358447L, 367745L, 370327L, 
380843L, 384989L, 398124L, 401205L, 404927L, 1L, 26372L, 1L, 
1L, 1L, 1L, 1L, 73656L, 79725L, 90824L, 95274L, 99904L), asm_end = c(5950L, 
3995L, 5177L, 5315L, 6235L, 4981L, 27818L, 45534L, 68264L, 130898L, 
5138L, 17020L, 30214L, 99717L, 109953L, 252043L, 461292L, 489600L, 
574546L, 619654L, 635391L, 804479L, 1044934L, 1061598L, 1245801L, 
1248774L, 1255939L, 1296194L, 1411355L, 1505311L, 1528580L, 1544546L, 
1567008L, 1913346L, 2023808L, 2074229L, 2114626L, 2152570L, 2181600L, 
5629L, 6264L, 5275L, 11603L, 39538L, 42705L, 57119L, 105678L, 
164117L, 186720L, 211604L, 218995L, 229730L, 242897L, 262044L, 
268076L, 286925L, 326640L, 346844L, 86702L, 236887L, 241797L, 
285058L, 304118L, 3951L, 8848L, 172544L, 199351L, 204571L, 209542L, 
228016L, 231274L, 246407L, 248747L, 251009L, 261848L, 265107L, 
268385L, 312594L, 320332L, 358306L, 367137L, 370091L, 380152L, 
384474L, 397963L, 400557L, 404679L, 417807L, 5977L, 42373L, 3581L, 
5829L, 7936L, 6150L, 15203L, 79624L, 89913L, 94045L, 98912L, 
104709L), cmp_start = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), cmp_end = c(5950L, 3995L, 
5177L, 5315L, 6235L, 4981L, 13291L, 17094L, 22317L, 61759L, 5138L, 
17020L, 30214L, 69237L, 9893L, 141990L, 209149L, 28208L, 84846L, 
45008L, 15637L, 167405L, 240355L, 16564L, 184103L, 2873L, 6711L, 
38186L, 110857L, 89306L, 22793L, 15866L, 22362L, 346238L, 110362L, 
50321L, 40297L, 37844L, 28930L, 5629L, 6264L, 5275L, 11603L, 
6722L, 3067L, 13665L, 42893L, 54838L, 22503L, 24784L, 6522L, 
10635L, 12874L, 18773L, 5636L, 4816L, 38845L, 7277L, 86702L, 
150085L, 4050L, 38609L, 16814L, 3951L, 8848L, 172544L, 20485L, 
5071L, 2481L, 18064L, 2026L, 14511L, 2094L, 2162L, 6723L, 3159L, 
2468L, 43397L, 7605L, 37475L, 8691L, 2347L, 9826L, 3632L, 12975L, 
2434L, 3475L, 12881L, 5977L, 16002L, 3581L, 5829L, 7936L, 6150L, 
15203L, 5969L, 10189L, 3222L, 3639L, 4806L), ori = c(1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L)), class = "data.frame", row.names = c(NA, -100L))
